<!-- 告警级别分布 -->
<template>
    <div class="device-type">
        <div class="header">
            <div class="header-title">告警级别分布</div>
        </div>
        <div ref="chartRef" style="width: 100%; min-height: 300px"></div>
    </div>
</template>
<script lang="ts" name="WarningLevel" setup>
import { useMenuStore } from '@/store/menu';
import * as echarts from 'echarts';

const chartRef = ref<Record<string, any>>({});
const menu = useMenuStore();
let myChart: any = null;

const handleOptions = (x = [], y = []) => {
    const chart: any = chartRef.value;
    if (chart) {
        myChart = echarts.init(chart);
        const options = {
            grid: {
                top: '10%',
                left: '3%',
                right: '4%',
                bottom: '8%',
                containLabel: true,
            },
            title: {
                text: 'Referer of a Website',
                subtext: 'Fake Data',
                left: 'center',
            },
            tooltip: {
                trigger: 'item',
            },
            legend: {
                bottom: '5%',
                left: 'center',
            },
            series: [
                {
                    name: 'Access From',
                    type: 'pie',
                    radius: '50%',
                    data: [
                        { value: 1048, name: 'Search Engine' },
                        { value: 735, name: 'Direct' },
                        { value: 580, name: 'Email' },
                        { value: 484, name: 'Union Ads' },
                        { value: 300, name: 'Video Ads' },
                    ],
                    emphasis: {
                        itemStyle: {
                            shadowBlur: 10,
                            shadowOffsetX: 0,
                            shadowColor: 'rgba(0, 0, 0, 0.5)',
                        },
                    },
                },
            ],
        };
        nextTick(() => {
            myChart.setOption(options);
            window.addEventListener('resize', function () {
                myChart.resize();
            });
        });
    }
};

watch(
    () => menu.collapsed,
    (newX) => {
        setTimeout(() => {
            myChart.resize();
        }, 300);
    },
);

onMounted(() => {
    handleOptions();
});
</script>
<style scoped lang="less">
.device-type {
    flex: 1;
    background: white;
    border-radius: 8px;
    margin-top: 16px;
    margin-left: 16px;
    padding: 16px 16px 16px 16px;
    .header {
        display: flex;
        align-items: center;
        justify-content: space-between;
        .header-title {
            border-left: 3px solid #3468ff;
            padding-left: 8px;
            font-size: 16px;
            font-family: PingFang SC-Medium, PingFang SC;
            font-weight: 500;
            color: #333333;
            line-height: 23px;
        }
    }
}
</style>
